@@ -6,9 +6,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.0';
-
-use DB::DataStore;
+$VERSION = '1.1';
 
 =head1 NAME
 
@@ -75,11 +73,11 @@ orthagonally to any other storage system.
 Starts up a persistance engine and returns it.
    
 =cut
-$Yote::STORES = {};
 sub open_store {
     my $path = pop;
-    $Yote::STORES->{$path} ||= Yote::ObjStore->_new( { store => $path } );
-    $Yote::STORES->{$path};
+    my $store = Yote::ObjStore->_new( { store => $path } );
+    $store->_init;
+    $store;
 }
 
 # ---------------------------------------------------------------------------------------------------------------------
@@ -92,13 +90,12 @@ no warnings 'numeric';
 no warnings 'uninitialized';
 no warnings 'recursion';
 
-use Crypt::Passwd::XS;
 use WeakRef;
 
 
 use vars qw($VERSION);
 
-$VERSION = '0.073';
+$VERSION = '1.1';
 
 =head1 NAME
 
@@ -170,6 +167,7 @@ sub _newroot {
 =cut
 sub fetch {
     my( $self, $id ) = @_;
+
     return undef unless $id;
     #
     # Return the object if we have a reference to its dirty state.
@@ -197,10 +195,12 @@ sub fetch {
             return \%hash;
         }
         else {
-            $class =~ /^Yote::(Root|Obj)/ || eval("require $class");
+            my $obj;
+            eval {
+                $class =~ /^Yote::/ || eval("require $class");
+                $obj = $class->_instantiate( $id, $self );
+            };
             return undef if $@;
-
-            my $obj = $class->_instantiate( $id, $self );
             $obj->{DATA} = $data;
             $obj->{ID} = $id;
             $obj->_load();
@@ -259,10 +259,15 @@ sub _new { #Yote::ObjStore
         _WEAK_REFS => {},
     }, $pkg;
     $self->{_DATASTORE} = Yote::YoteDB->open( $self, $args );
+    $self;
+} #_new
+
+sub _init {
+    my $self = shift;
     $self->fetch_root;
     $self->stow_all;
     $self;
-} #_new
+}
 
 
 #
@@ -393,6 +398,7 @@ sub _stow {
             }
         }
     }
+    $id;
 } #_stow
 
 sub _xform_in {
@@ -500,6 +506,10 @@ use strict;
 use warnings;
 no  warnings 'uninitialized';
 
+use vars qw($VERSION);
+
+$VERSION = '1.1';
+
 #
 # The string version of the yote object is simply its id. This allows
 # objet ids to easily be stored as hash keys.
@@ -512,6 +522,8 @@ use overload
     '!='   => sub { ! ref($_[1]) || $_[1]->{ID} != $_[0]->{ID} },
     fallback => 1;
 
+# add a get()/set() here?
+
 # -----------------------
 #
 #     Public Methods
@@ -705,7 +717,7 @@ use Tie::Array;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '1.1';
 
 sub TIEARRAY {
     my( $class, $obj_store, $id, @list ) = @_;
@@ -800,7 +812,7 @@ use Tie::Hash;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '1.1';
 
 sub TIEHASH {
     my( $class, $obj_store, $id, %hash ) = @_;
@@ -859,6 +871,8 @@ use warnings;
 
 no warnings 'uninitialized';
 
+use DB::DataStore;
+
 use WeakRef;
 use File::Path qw(make_path);
 use JSON;
@@ -866,13 +880,13 @@ use JSON;
 use Devel::Refcount 'refcount';
 
 use constant {
-  ID => 0,
-  CLASS => 1,
   DATA => 2,
-  RAW_DATA => 2,
-  MAX_LENGTH => 1025,
 };
 
+use vars qw($VERSION);
+
+$VERSION = '1.1';
+
 #
 # This the main index and stores in which table and position
 # in that table that this object lives.
@@ -1049,10 +1063,12 @@ __END__
 =head1 AUTHOR
        Eric Wolf        coyocanid@gmail.com
 
+=head1 COPYRIGHT AND LICENSE
+
        Copyright (c) 2015 Eric Wolf. All rights reserved.  This program is free software; you can redistribute it and/or modify it
        under the same terms as Perl itself.
 
 =head1 VERSION
-       Version 1.0  (October 10, 2015))
+       Version 1.1  (October 10, 2015))
 
 =cut
